==> open-cluster-management-apps-model-5.12.1-sources.jar: io/fabric8/openclustermanagement/api/model/multicloudoperatorssubscription/apps/helmrelease/v1/HelmReleaseRepoBuilder.java <==
package io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.helmrelease.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class HelmReleaseRepoBuilder extends io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.helmrelease.v1.HelmReleaseRepoFluentImpl<io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.helmrelease.v1.HelmReleaseRepoBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.helmrelease.v1.HelmReleaseRepo,io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.helmrelease.v1.HelmReleaseRepoBuilder>{
  public HelmReleaseRepoBuilder() {
    this(false);
  }
  public HelmReleaseRepoBuilder(java.lang.Boolean validationEnabled) {
    this(new HelmReleaseRepo(), validationEnabled);
  }
  public HelmReleaseRepoBuilder(io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.helmrelease.v1.HelmReleaseRepoFluent<?> fluent) {
    this(fluent, false);
  }
  public HelmReleaseRepoBuilder(io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.helmrelease.v1.HelmReleaseRepoFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new HelmReleaseRepo(), validationEnabled);
  }
  public HelmReleaseRepoBuilder(io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.helmrelease.v1.HelmReleaseRepoFluent<?> fluent,io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.helmrelease.v1.HelmReleaseRepo instance) {
    this(fluent, instance, false);
  }
  public HelmReleaseRepoBuilder(io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.helmrelease.v1.HelmReleaseRepoFluent<?> fluent,io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.helmrelease.v1.HelmReleaseRepo instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAltSource(instance.getAltSource()); 
    fluent.withChartName(instance.getChartName()); 
    fluent.withConfigMapRef(instance.getConfigMapRef()); 
    fluent.withDigest(instance.getDigest()); 
    fluent.withInsecureSkipVerify(instance.getInsecureSkipVerify()); 
    fluent.withSecretRef(instance.getSecretRef()); 
    fluent.withSource(instance.getSource()); 
    fluent.withVersion(instance.getVersion()); 
    this.validationEnabled = validationEnabled; 
  }
  public HelmReleaseRepoBuilder(io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.helmrelease.v1.HelmReleaseRepo instance) {
    this(instance,false);
  }
  public HelmReleaseRepoBuilder(io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.helmrelease.v1.HelmReleaseRepo instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withAltSource(instance.getAltSource()); 
    this.withChartName(instance.getChartName()); 
    this.withConfigMapRef(instance.getConfigMapRef()); 
    this.withDigest(instance.getDigest()); 
    this.withInsecureSkipVerify(instance.getInsecureSkipVerify()); 
    this.withSecretRef(instance.getSecretRef()); 
    this.withSource(instance.getSource()); 
    this.withVersion(instance.getVersion()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.helmrelease.v1.HelmReleaseRepoFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.helmrelease.v1.HelmReleaseRepo build() {
    HelmReleaseRepo buildable = new HelmReleaseRepo(fluent.getAltSource(),fluent.getChartName(),fluent.getConfigMapRef(),fluent.getDigest(),fluent.getInsecureSkipVerify(),fluent.getSecretRef(),fluent.getSource(),fluent.getVersion());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    HelmReleaseRepoBuilder that = (HelmReleaseRepoBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> open-cluster-management-apps-model-6.6.0-sources.jar: io/fabric8/openclustermanagement/api/model/multicloudoperatorssubscription/apps/helmrelease/v1/HelmReleaseRepoBuilder.java <==
package io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.helmrelease.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class HelmReleaseRepoBuilder extends HelmReleaseRepoFluentImpl<HelmReleaseRepoBuilder> implements VisitableBuilder<HelmReleaseRepo,HelmReleaseRepoBuilder>{
  public HelmReleaseRepoBuilder() {
    this(false);
  }
  public HelmReleaseRepoBuilder(Boolean validationEnabled) {
    this(new HelmReleaseRepo(), validationEnabled);
  }
  public HelmReleaseRepoBuilder(HelmReleaseRepoFluent<?> fluent) {
    this(fluent, false);
  }
  public HelmReleaseRepoBuilder(HelmReleaseRepoFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new HelmReleaseRepo(), validationEnabled);
  }
  public HelmReleaseRepoBuilder(HelmReleaseRepoFluent<?> fluent,HelmReleaseRepo instance) {
    this(fluent, instance, false);
  }
  public HelmReleaseRepoBuilder(HelmReleaseRepoFluent<?> fluent,HelmReleaseRepo instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withAltSource(instance.getAltSource()); 
    fluent.withChartName(instance.getChartName()); 
    fluent.withConfigMapRef(instance.getConfigMapRef()); 
    fluent.withDigest(instance.getDigest()); 
    fluent.withInsecureSkipVerify(instance.getInsecureSkipVerify()); 
    fluent.withSecretRef(instance.getSecretRef()); 
    fluent.withSource(instance.getSource()); 
    fluent.withVersion(instance.getVersion()); 
    this.validationEnabled = validationEnabled; 
  }
  public HelmReleaseRepoBuilder(HelmReleaseRepo instance) {
    this(instance,false);
  }
  public HelmReleaseRepoBuilder(HelmReleaseRepo instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withAltSource(instance.getAltSource()); 
    this.withChartName(instance.getChartName()); 
    this.withConfigMapRef(instance.getConfigMapRef()); 
    this.withDigest(instance.getDigest()); 
    this.withInsecureSkipVerify(instance.getInsecureSkipVerify()); 
    this.withSecretRef(instance.getSecretRef()); 
    this.withSource(instance.getSource()); 
    this.withVersion(instance.getVersion()); 
    this.validationEnabled = validationEnabled; 
  }
  HelmReleaseRepoFluent<?> fluent;
  Boolean validationEnabled;
  public HelmReleaseRepo build() {
    HelmReleaseRepo buildable = new HelmReleaseRepo(fluent.getAltSource(),fluent.getChartName(),fluent.getConfigMapRef(),fluent.getDigest(),fluent.getInsecureSkipVerify(),fluent.getSecretRef(),fluent.getSource(),fluent.getVersion());
    return buildable;
  }
  
}
